==> jumbo-fax-1.0.tar.gz: jumbo-fax-1.0/fax/admin.py <==
# -*- coding: utf-8 -*-
import datetime

from django.contrib import admin
from django.utils.translation import ugettext as _
from django import forms
from django.conf import settings

from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.core.urlresolvers import reverse
from jumbo.apps.autocomplete import autocomplete
from jumbo.forms.widgets import DateWidget

from organization.models import Organization
from fax.models import Fax, Device, Settings, FaxNumber, FaxPermission, STATUS_CODES
from fax import views as fax_views

####################################
# Registro il campo autocomplete
####################################
def get_organization_number(request, query):
    return Organization.objects.filter(status=1).order_by('name')

autocomplete.register('fax_organization', model = Organization, views = get_organization_number,
                      search_fields = ('name','fax'),
                      limit=5, label=lambda obj: get_recipient_number_label(obj))

# Personalizzo la label di visualizzazione
def get_recipient_number_label(obj):
    return "%s - %s" % (obj.name, obj.fax)


class FaxSearchForm(forms.ModelForm):
    class Meta:
        model = Fax
        fields = ('recipient', )
        display_fields = (('status', 'subject__icontains',),
                          ('recipient_number__icontains', 'recipient__icontains'),
                          ('date_create__year','search_in_all_years'),
                          ('sender__icontains','sender_number__icontains'),
                          ('date_sent__range_from','date_sent__range_to'),
            )

    def __init__(self, *args, **kws):
        super(FaxSearchForm, self).__init__(*args, **kws)
        codes = list(STATUS_CODES)
        codes.insert(0, ('', '-------'))
        self.fields['status'] = forms.ChoiceField(choices=codes, label=_("Status"), required=False)
        self.fields['subject__icontains'] = forms.CharField(label=_("Subject"), required=False)
        self.fields['recipient_number__icontains'] = forms.CharField(label=_("Recipient Number"), required=False)
        self.fields['recipient__icontains'] = forms.CharField(label=_("Recipient"), required=False)
        self.fields['search_in_all_years'] = forms.BooleanField(label=_("Search In All Years"), required=False)
        self.fields['date_create__year'] = forms.CharField(label=_("Year"), required=False)
        self.fields['sender__icontains'] = forms.CharField(label=_("Sender"), required=False)
        self.fields['sender_number__icontains']= forms.CharField(label=_("sender number"), required=False)

        self.fields['date_sent__range_from'] = forms.DateField(input_formats='%Y,%m,%d',widget=DateWidget())
        self.fields['date_sent__range_to'] = forms.DateField(input_formats='%Y,%m,%d', widget=DateWidget())

#        end_date = forms.DateField(input_formats='%Y,%m,%d',widget=SelectDateWidget())
    # Modifico il filtro di ricerca in modo da filtrare sempre in base all'anno corrente, tranne nel caso in cui
    # nei parametri di ricerca venga specificato un anno oppure venga flaggata la checkbox search_in_all_years

    def change_search_filter(self, lookup_params, qs):
        if not lookup_params.has_key('date_create__year') and not lookup_params.has_key('search_in_all_years'):
            qs = qs.filter(date_create__year = datetime.date.today().year)

        if lookup_params.has_key('search_in_all_years'):
            del lookup_params['search_in_all_years']
        return lookup_params, qs


class FaxAdmin(ExtendibleModelAdmin):
    list_title = _('List Fax')
    list_display = ['date_create', 'device', 'get_subject', 'date_sent', 'get_status', 'recipient', 'recipient_number',
                    'submitter', 'sender', 'get_notify_group', 'get_pages', 'get_read', 'get_report', 'get_cover',
                    'forward', 'get_delete_icon']
    search_form = FaxSearchForm
    actions = None #[]
    #date_hierarchy = 'date_create'


    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        urls = super(FaxAdmin, self).get_urls()
        my_urls = patterns('',
            url(r'^add/$'                             , self.admin_site.admin_view(fax_views.fax_send)
                                                      , name='fax_fax_add'),
            url(r'^(?P<object_id>\d+)/$'              , self.admin_site.admin_view(fax_views.fax_change)
                                                      , name='fax_fax_change'),
            url(r'^(?P<object_id>\d+)/pdf/download/$' , self.admin_site.admin_view(fax_views.download_pdf)
                                                      , name='fax_fax_download'),
            url(r'^(?P<object_id>\d+)/pdf/report/$'   , self.admin_site.admin_view(fax_views.report_pdf)
                                                      , name='fax_fax_report'),
            url(r'^(?P<object_id>\d+)/cover/download/$' , self.admin_site.admin_view(fax_views.download_cover)
                                                        , name='fax_fax_downloadcover'),
            url(r'^(?P<object_id>\d+)/forward/$'      , self.admin_site.admin_view(fax_views.fax_forward)
                                                      , name='fax_fax_forward'),
        )
        return my_urls + urls


    def has_delete_permission(self, request, obj=None):
        """
        Returns True if the given request has permission to change the given
        Django model instance.

        If `obj` is None, this should return True if the given request has
        permission to delete *any* object of the given type.
        """
        if request.user.is_superuser:
            return True

        if obj:
            if obj.can_be_delete():
                return True

        return False


    def get_subject(self, obj):
        if obj.status == 8:
            return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_forward', obj.id), obj.subject)
        return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_change', obj.id), obj.subject)
    get_subject.short_description = _('Subject')
    get_subject.allow_tags = True
    get_subject.admin_order_field = 'subject'


    def get_read(self, obj):
        if not obj.file:
            return ""

        image = None
        description = ''
        if not obj.read:
            description = _('Not Read')
            image = 'fax_unread.png'
        if obj.read == 1:
            description = _('Read')
            image = 'fax_read.png'

        return '<a href="%(url)s"><img src="%(media_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/></a>' % {
                'url': reverse('admin:fax_fax_download', obj.id),
                'media_url' : settings.MEDIA_URL,
                'image' : image,
                'description': description
      }
    get_read.short_description = _('RD')
    get_read.allow_tags = True


    def get_status(self, obj):
        if obj.status == 2:
            description = _('Received')
            image = 'fax_in.png'
        elif obj.status == 3:
            description = _('Queued')
            image = 'fax_queue.png'
        elif obj.status == 4:
            description = _('Sent')
            image = 'fax_out.png'
        elif obj.status == 5:
            description = obj.error
            image = 'fax_error.png'
        elif obj.status == 6:
            description = _('Multi Queued')
            image = 'all_fax.png'
        elif obj.status == 7:
            description = _('Multi Sent')
            image = 'all_fax.png'
        elif obj.status == 8:
            description = _('To Send')
            image = 'fax_to_send.png'

        return '<img src="%(media_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>' % {
                                         'media_url' : settings.MEDIA_URL,
                                         'image' : image,
                                         'description': description}
    get_status.short_description = _('ST')
    get_status.allow_tags = True


    def get_pages(self, obj):
        return obj.pages or ""
    get_pages.short_description = _("Pag.")


    def get_notify_group(self, obj):
        return obj.notify_group or ""
    get_notify_group.short_description = _("notify group")


    def get_report(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return '<a href="%(url)s"><img src="%(media_url)sfax/images/report.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_report', obj.id),
             'media_url' : settings.MEDIA_URL,
             'description': _("Report PDF")}
        return ""
    get_report.short_description = _("RP")
    get_report.allow_tags = True


    def get_cover(self, obj):
        if obj.cover_fax:
            return '<a href="%(url)s"><img src="%(media_url)sadmin/images/pdf_icon.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_downloadcover', obj.id),
                 'media_url' : settings.MEDIA_URL,
                 'description': _("Cover PDF")}
        return ""
    get_cover.short_description = _("CO")
    get_cover.allow_tags = True


    def forward(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return '<a href="%(url)s"><img src="%(media_url)sfax/images/inoltra.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_forward', obj.id),
             'media_url' : settings.MEDIA_URL,
             'description': _("Forward")}
        return ""
    forward.short_description = _("FW")
    forward.allow_tags = True


class DeviceAdmin(ExtendibleModelAdmin):
    list_display = ['name', 'description', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
                  (_("General Information"), {'fields' : ('name', 'description')}),
                )

class FaxNumberAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ['name', 'number', 'get_device', 'move_actions', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
                  (_("General Information"), {'fields' : ('status', 'ordering', 'name', 'number', 'device')}),
                  (_("Notify Email"), {'fields' : ('notify_mails', 'send_at_received_fax', 'send_at_sent_fax',)}),
                )

    def get_device(self, obj):
        str_device = ""
        for d in obj.device.all():
            str_device += "%s | " % d.name
        return str_device
    get_device.short_description = _("Device")


admin.site.register(Fax, FaxAdmin)
admin.site.register(Device, DeviceAdmin)
admin.site.register(FaxNumber, FaxNumberAdmin)
admin.site.register(Settings, SettingsAdmin)
admin.site.register(FaxPermission)

==> jumbo-fax-1.0.1.tar.gz: jumbo-fax-1.0.1/fax/admin.py <==
# -*- coding: utf-8 -*-
import datetime

from django.contrib import admin
from django.utils.translation import ugettext as _
from django import forms
from django.conf import settings

from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.core.urlresolvers import reverse
from jumbo.apps.autocomplete import autocomplete
from jumbo.forms.widgets import DateWidget

from organization.models import Organization
from fax.models import Fax, Device, Settings, FaxNumber, FaxPermission, STATUS_CODES
from fax import views as fax_views

####################################
# Registro il campo autocomplete
####################################
def get_organization_number(request, query):
    return Organization.objects.filter(status=1).order_by('name')

autocomplete.register('fax_organization', model = Organization, views = get_organization_number,
                      search_fields = ('name','fax'),
                      limit=5, label=lambda obj: get_recipient_number_label(obj))

# Personalizzo la label di visualizzazione
def get_recipient_number_label(obj):
    return "%s - %s" % (obj.name, obj.fax)


class FaxSearchForm(forms.ModelForm):
    class Meta:
        model = Fax
        fields = ('recipient', )
        display_fields = (('status', 'subject__icontains',),
                          ('recipient_number__icontains', 'recipient__icontains'),
                          ('date_create__year','search_in_all_years'),
                          ('sender__icontains','sender_number__icontains'),
                          ('date_sent__range_from','date_sent__range_to'),
            )

    def __init__(self, *args, **kws):
        super(FaxSearchForm, self).__init__(*args, **kws)
        codes = list(STATUS_CODES)
        codes.insert(0, ('', '-------'))
        self.fields['status'] = forms.ChoiceField(choices=codes, label=_("Status"), required=False)
        self.fields['subject__icontains'] = forms.CharField(label=_("Subject"), required=False)
        self.fields['recipient_number__icontains'] = forms.CharField(label=_("Recipient Number"), required=False)
        self.fields['recipient__icontains'] = forms.CharField(label=_("Recipient"), required=False)
        self.fields['search_in_all_years'] = forms.BooleanField(label=_("Search In All Years"), required=False)
        self.fields['date_create__year'] = forms.CharField(label=_("Year"), required=False)
        self.fields['sender__icontains'] = forms.CharField(label=_("Sender"), required=False)
        self.fields['sender_number__icontains']= forms.CharField(label=_("sender number"), required=False)

        self.fields['date_sent__range_from'] = forms.DateField(input_formats='%Y,%m,%d',widget=DateWidget())
        self.fields['date_sent__range_to'] = forms.DateField(input_formats='%Y,%m,%d', widget=DateWidget())

#        end_date = forms.DateField(input_formats='%Y,%m,%d',widget=SelectDateWidget())
    # Modifico il filtro di ricerca in modo da filtrare sempre in base all'anno corrente, tranne nel caso in cui
    # nei parametri di ricerca venga specificato un anno oppure venga flaggata la checkbox search_in_all_years

    def change_search_filter(self, lookup_params, qs):
        if not lookup_params.has_key('date_create__year') and not lookup_params.has_key('search_in_all_years'):
            qs = qs.filter(date_create__year = datetime.date.today().year)

        if lookup_params.has_key('search_in_all_years'):
            del lookup_params['search_in_all_years']
        return lookup_params, qs


class FaxAdmin(ExtendibleModelAdmin):
    list_title = _('List Fax')
    list_display = ['date_sent', 'device', 'get_subject', 'date_create', 'get_status', 'recipient', 'recipient_number',
                    'submitter', 'sender', 'get_notify_group', 'get_pages', 'get_read', 'get_report', 'get_cover',
                    'forward', 'get_delete_icon']
    search_form = FaxSearchForm
    actions = None #[]
    #date_hierarchy = 'date_create'


    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        urls = super(FaxAdmin, self).get_urls()
        my_urls = patterns('',
            url(r'^add/$'                             , self.admin_site.admin_view(fax_views.fax_send)
                                                      , name='fax_fax_add'),
            url(r'^(?P<object_id>\d+)/$'              , self.admin_site.admin_view(fax_views.fax_change)
                                                      , name='fax_fax_change'),
            url(r'^(?P<object_id>\d+)/pdf/download/$' , self.admin_site.admin_view(fax_views.download_pdf)
                                                      , name='fax_fax_download'),
            url(r'^(?P<object_id>\d+)/pdf/report/$'   , self.admin_site.admin_view(fax_views.report_pdf)
                                                      , name='fax_fax_report'),
            url(r'^(?P<object_id>\d+)/cover/download/$' , self.admin_site.admin_view(fax_views.download_cover)
                                                        , name='fax_fax_downloadcover'),
            url(r'^(?P<object_id>\d+)/forward/$'      , self.admin_site.admin_view(fax_views.fax_forward)
                                                      , name='fax_fax_forward'),
        )
        return my_urls + urls


    def has_delete_permission(self, request, obj=None):
        """
        Returns True if the given request has permission to change the given
        Django model instance.

        If `obj` is None, this should return True if the given request has
        permission to delete *any* object of the given type.
        """
        if request.user.is_superuser:
            return True

        if obj:
            if obj.can_be_delete():
                return True

        return False


    def get_subject(self, obj):
        if obj.status == 8:
            return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_forward', obj.id), obj.subject)
        return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_change', obj.id), obj.subject)
    get_subject.short_description = _('Subject')
    get_subject.allow_tags = True
    get_subject.admin_order_field = 'subject'


    def get_read(self, obj):
        if not obj.file:
            return ""

        image = None
        description = ''
        if not obj.read:
            description = _('Not Read')
            image = 'fax_unread.png'
        if obj.read == 1:
            description = _('Read')
            image = 'fax_read.png'

        return '<a href="%(url)s"><img src="%(media_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/></a>' % {
                'url': reverse('admin:fax_fax_download', obj.id),
                'media_url' : settings.MEDIA_URL,
                'image' : image,
                'description': description
      }
    get_read.short_description = _('RD')
    get_read.allow_tags = True


    def get_status(self, obj):
        if obj.status == 2:
            description = _('Received')
            image = 'fax_in.png'
        elif obj.status == 3:
            description = _('Queued')
            image = 'fax_queue.png'
        elif obj.status == 4:
            description = _('Sent')
            image = 'fax_out.png'
        elif obj.status == 5:
            description = obj.error
            image = 'fax_error.png'
        elif obj.status == 6:
            description = _('Multi Queued')
            image = 'all_fax.png'
        elif obj.status == 7:
            description = _('Multi Sent')
            image = 'all_fax.png'
        elif obj.status == 8:
            description = _('To Send')
            image = 'fax_to_send.png'

        return '<img src="%(media_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>' % {
                                         'media_url' : settings.MEDIA_URL,
                                         'image' : image,
                                         'description': description}
    get_status.short_description = _('ST')
    get_status.allow_tags = True


    def get_pages(self, obj):
        return obj.pages or ""
    get_pages.short_description = _("Pag.")


    def get_notify_group(self, obj):
        return obj.notify_group or ""
    get_notify_group.short_description = _("notify group")


    def get_report(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return '<a href="%(url)s"><img src="%(media_url)sfax/images/report.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_report', obj.id),
             'media_url' : settings.MEDIA_URL,
             'description': _("Report PDF")}
        return ""
    get_report.short_description = _("RP")
    get_report.allow_tags = True


    def get_cover(self, obj):
        if obj.cover_fax:
            return '<a href="%(url)s"><img src="%(media_url)sadmin/images/pdf_icon.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_downloadcover', obj.id),
                 'media_url' : settings.MEDIA_URL,
                 'description': _("Cover PDF")}
        return ""
    get_cover.short_description = _("CO")
    get_cover.allow_tags = True


    def forward(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return '<a href="%(url)s"><img src="%(media_url)sfax/images/inoltra.png" alt="%(description)s" title="%(description)s"/></a>' % {'url' : reverse('admin:fax_fax_forward', obj.id),
             'media_url' : settings.MEDIA_URL,
             'description': _("Forward")}
        return ""
    forward.short_description = _("FW")
    forward.allow_tags = True


class DeviceAdmin(ExtendibleModelAdmin):
    list_display = ['name', 'description', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
                  (_("General Information"), {'fields' : ('name', 'description')}),
                )

class FaxNumberAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ['name', 'number', 'get_device', 'move_actions', 'get_edit_icon', 'get_delete_icon']
    fieldsets = (
                  (_("General Information"), {'fields' : ('status', 'ordering', 'name', 'number', 'device')}),
                  (_("Notify Email"), {'fields' : ('notify_mails', 'send_at_received_fax', 'send_at_sent_fax',)}),
                )

    def get_device(self, obj):
        str_device = ""
        for d in obj.device.all():
            str_device += "%s | " % d.name
        return str_device
    get_device.short_description = _("Device")


admin.site.register(Fax, FaxAdmin)
admin.site.register(Device, DeviceAdmin)
admin.site.register(FaxNumber, FaxNumberAdmin)
admin.site.register(Settings, SettingsAdmin)
admin.site.register(FaxPermission)
